@@ -18,17 +18,17 @@
 #ifndef KEYBOARDLAYOUTEDITORVIEW_H
 #define KEYBOARDLAYOUTEDITORVIEW_H
 
-#include <QDeclarativeView>
+#include <QQuickWidget>
 
-class KeyboardLayoutEditorView : public QDeclarativeView
+class KeyboardLayoutEditorView : public QQuickWidget
 {
     Q_OBJECT
 public:
-    explicit KeyboardLayoutEditorView(QWidget* parent = 0);
+    explicit KeyboardLayoutEditorView(QWidget* parent = nullptr);
 signals:
     void clicked();
 protected:
-    virtual void mousePressEvent(QMouseEvent* event);
+    void mousePressEvent(QMouseEvent* event) override;
 };
 
 #endif // KEYBOARDLAYOUTEDITORVIEW_H
